@@ -15,9 +15,28 @@ def parse_args(args: Sequence[str] = None) -> argparse.Namespace:
         prog="yaml2jsonnet",
         description="Convert a YAML file to a JSONNET file, preserving comments",
     )
-    parser.add_argument("yaml", type=argparse.FileType("r"))
-    parser.add_argument("--out", default=sys.stdout, type=argparse.FileType("w"))
-    parser.add_argument("-v", action="count", default=0)
+    parser.add_argument(
+        "yaml", type=argparse.FileType("r"), help="YAML file to convert"
+    )
+    parser.add_argument(
+        "-o",
+        "--out",
+        default=sys.stdout,
+        type=argparse.FileType("w"),
+        help="File to write out to (or stdout)",
+    )
+    parser.add_argument(
+        "-c",
+        "--document-comments",
+        type=bool,
+        help="Add comments about which YAML document produced which map",
+    )
+    parser.add_argument(
+        "-v",
+        action="count",
+        default=0,
+        help="Logging verbosity: one for info, two for debug",
+    )
 
     return parser.parse_args(args)
 
@@ -25,7 +44,7 @@ def parse_args(args: Sequence[str] = None) -> argparse.Namespace:
 def run(args: argparse.Namespace) -> None:
     log.debug("Read yaml into memory")
     yaml_data = args.yaml.read()
-    convert_yaml(yaml_data, args.out)
+    convert_yaml(yaml_data, args.out, args.document_comments)
 
 
 def main() -> None:
@@ -37,3 +56,4 @@ def main() -> None:
         loglevel = logging.DEBUG
     logging.basicConfig(level=loglevel)
     run(args)
+    args.out.close()
